@@ -1,3 +1,5 @@
+use super::Iconize;
+use crate::Icon;
 use bytesize::ByteSize;
 use std::fmt;
 
@@ -29,6 +31,12 @@ impl MemoryFormatter {
     }
 }
 
+impl Iconize for MemoryFormatter {
+    fn set_icon(&self, icon: &mut Icon) {
+        icon.find_icon("media-floppy-symbolic")
+    }
+}
+
 impl fmt::Display for MemoryFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
